@@ -43,7 +43,8 @@ public:
     int verticalMargin;
     int iconSize;
     bool extendedSelectionRegion;
-    QSize maxTextSize;
+    int maxTextLines;
+    int maxTextWidth;
 };
 #endif
 
