@@ -56,7 +56,7 @@ QString tolerantFromAce (const QByteArray& _domain)
     const bool hasDot = domain.startsWith ('.');
     if (hasDot)
         domain.remove (0, 1);
-    QString ret = QUrl::fromAce (domain);
+    QString ret = QUrl::fromAce(domain);
     if (hasDot) {
         ret.prepend ('.');
     }
@@ -81,7 +81,7 @@ KCookiesPolicies::KCookiesPolicies (const KComponentData& componentData, QWidget
     : KCModule (componentData, parent)
 {
     mUi.setupUi (this);
-    mUi.kListViewSearchLine->setTreeWidget (mUi.lvDomainPolicy);
+    mUi.kListViewSearchLine->setTreeWidget (mUi.policyTreeWidget);
     QList<int> columns;
     columns.append (0);
     mUi.kListViewSearchLine->setSearchColumns (columns);
@@ -102,24 +102,19 @@ KCookiesPolicies::KCookiesPolicies (const KComponentData& componentData, QWidget
              SLOT (configChanged()));
     connect (mUi.cbAutoAcceptSessionCookies, SIGNAL (toggled (bool)),
              SLOT (configChanged()));
-    connect (mUi.cbIgnoreCookieExpirationDate, SIGNAL (toggled (bool)),
-             SLOT (configChanged()));
-
-    connect (mUi.cbAutoAcceptSessionCookies, SIGNAL (toggled (bool)),
-             SLOT (autoAcceptSessionCookies (bool)));
-    connect (mUi.cbIgnoreCookieExpirationDate, SIGNAL (toggled (bool)),
-             SLOT (ignoreCookieExpirationDate (bool)));
 
     connect (mUi.rbPolicyAsk, SIGNAL (toggled (bool)),
              SLOT (configChanged()));
     connect (mUi.rbPolicyAccept, SIGNAL (toggled (bool)),
              SLOT (configChanged()));
+    connect (mUi.rbPolicyAcceptForSession, SIGNAL(toggled(bool)),
+              SLOT(configChanged()));
     connect (mUi.rbPolicyReject, SIGNAL (toggled (bool)),
              SLOT (configChanged()));
     // Connect signals from the domain specific policy listview.
-    connect (mUi.lvDomainPolicy, SIGNAL (itemSelectionChanged()),
+    connect (mUi.policyTreeWidget, SIGNAL (itemSelectionChanged()),
              SLOT (selectionChanged()));
-    connect (mUi.lvDomainPolicy, SIGNAL (itemDoubleClicked (QTreeWidgetItem*, int)),
+    connect (mUi.policyTreeWidget, SIGNAL (itemDoubleClicked (QTreeWidgetItem*, int)),
              SLOT (changePressed()));
 
     // Connect the buttons...
@@ -144,36 +139,64 @@ void KCookiesPolicies::cookiesEnabled (bool enable)
     mUi.bgDefault->setEnabled (enable);
     mUi.bgPreferences->setEnabled (enable);
     mUi.gbDomainSpecific->setEnabled (enable);
+}
 
-    if (enable) {
-        ignoreCookieExpirationDate (enable);
-        autoAcceptSessionCookies (enable);
+void KCookiesPolicies::setPolicy (const QString& domain)
+{
+    QTreeWidgetItemIterator it (mUi.policyTreeWidget);
+    bool hasExistingPolicy = false;
+    while (*it) {
+        if ((*it)->text(0) == domain) {
+            hasExistingPolicy = true;
+            break;
+        }
+        ++it;
+    }
+
+    if (hasExistingPolicy) {
+        changePressed((*it), false);
+    } else {
+        addPressed(domain);
     }
 }
 
-void KCookiesPolicies::ignoreCookieExpirationDate (bool enable)
+void KCookiesPolicies::changePressed()
 {
-    bool isAutoAcceptChecked = mUi.cbAutoAcceptSessionCookies->isChecked();
-    enable = (enable && isAutoAcceptChecked);
-
-    mUi.bgDefault->setEnabled (!enable);
-    mUi.gbDomainSpecific->setEnabled (!enable);
+    changePressed(mUi.policyTreeWidget->currentItem());
 }
 
-void KCookiesPolicies::autoAcceptSessionCookies (bool enable)
+void KCookiesPolicies::addPressed()
 {
-    bool isIgnoreExpirationChecked = mUi.cbIgnoreCookieExpirationDate->isChecked();
-    enable = (enable && isIgnoreExpirationChecked);
-
-    mUi.bgDefault->setEnabled (!enable);
-    mUi.gbDomainSpecific->setEnabled (!enable);
+    addPressed(QString());
 }
 
-void KCookiesPolicies::addNewPolicy (const QString& domain)
+void KCookiesPolicies::changePressed(QTreeWidgetItem* item, bool state)
+{
+    Q_ASSERT(item);
+    const QString oldDomain(item->text (0));
+
+    KCookiesPolicySelectionDlg pdlg (this);
+    pdlg.setWindowTitle (i18nc ("@title:window", "Change Cookie Policy"));
+    pdlg.setPolicy (KCookieAdvice::strToAdvice (mDomainPolicyMap.value(oldDomain)));
+    pdlg.setEnableHostEdit (state, oldDomain);
+
+    if (pdlg.exec() && !pdlg.domain().isEmpty()) {
+        const QString newDomain = tolerantFromAce (pdlg.domain().toLatin1());
+        int advice = pdlg.advice();
+        if (newDomain == oldDomain || !handleDuplicate (newDomain, advice)) {
+            mDomainPolicyMap[newDomain] = KCookieAdvice::adviceToStr(advice);
+            item->setText(0, newDomain);
+            item->setText(1, i18n (mDomainPolicyMap.value(newDomain)));
+            configChanged();
+        }
+    }
+}
+
+void KCookiesPolicies::addPressed(const QString& domain, bool state)
 {
     KCookiesPolicySelectionDlg pdlg (this);
     pdlg.setWindowTitle (i18nc ("@title:window", "New Cookie Policy"));
-    pdlg.setEnableHostEdit (true, domain);
+    pdlg.setEnableHostEdit(state, domain);
 
     if (mUi.rbPolicyAccept->isChecked())
         pdlg.setPolicy (KCookieAdvice::Reject);
@@ -182,69 +205,39 @@ void KCookiesPolicies::addNewPolicy (const QString& domain)
 
     if (pdlg.exec() && !pdlg.domain().isEmpty()) {
         const QString domain = tolerantFromAce (pdlg.domain().toLatin1());
-        const int advice = pdlg.advice();
+        int advice = pdlg.advice();
 
         if (!handleDuplicate (domain, advice)) {
             const char* strAdvice = KCookieAdvice::adviceToStr (advice);
-            new QTreeWidgetItem (mUi.lvDomainPolicy, QStringList() << domain << i18n (strAdvice));
-            m_pDomainPolicy.insert (domain, strAdvice);
-            configChanged();
-        }
-    }
-}
-
-
-void KCookiesPolicies::addPressed()
-{
-    addNewPolicy (QString());
-}
-
-void KCookiesPolicies::changePressed()
-{
-    QTreeWidgetItem* item = mUi.lvDomainPolicy->currentItem();
-
-    if (!item)
-        return;
-
-    const QString oldDomain = item->text(0);
-    KCookiesPolicySelectionDlg pdlg (this);
-    pdlg.setWindowTitle (i18nc ("@title:window", "Change Cookie Policy"));
-    pdlg.setPolicy (KCookieAdvice::strToAdvice (m_pDomainPolicy.value(oldDomain)));
-    pdlg.setEnableHostEdit (true, oldDomain);
-
-    if (pdlg.exec() && !pdlg.domain().isEmpty()) {
-        const QString newDomain = tolerantFromAce (pdlg.domain().toLatin1());
-        const int advice = pdlg.advice();
-        if (newDomain == oldDomain || !handleDuplicate (newDomain, advice)) {
-            m_pDomainPolicy[newDomain] = KCookieAdvice::adviceToStr (advice);
-            item->setText (0, newDomain);
-            item->setText (1, i18n (m_pDomainPolicy.value(newDomain)));
+            QTreeWidgetItem* item = new QTreeWidgetItem (mUi.policyTreeWidget, QStringList() << domain << i18n (strAdvice));
+            mDomainPolicyMap.insert (item->text(0), strAdvice);
             configChanged();
+            updateButtons();
         }
     }
 }
 
 bool KCookiesPolicies::handleDuplicate (const QString& domain, int advice)
 {
-    QTreeWidgetItem* item = mUi.lvDomainPolicy->topLevelItem (0);
+    QTreeWidgetItem* item = mUi.policyTreeWidget->topLevelItem (0);
     while (item != 0) {
         if (item->text (0) == domain) {
-            QString msg = i18n ("<qt>A policy already exists for"
-                                "<center><b>%1</b></center>"
-                                "Do you want to replace it?</qt>", domain);
-            int res = KMessageBox::warningContinueCancel (this, msg,
-                      i18nc ("@title:window", "Duplicate Policy"),
-                      KGuiItem (i18n ("Replace")));
+            const int res = KMessageBox::warningContinueCancel (this,
+                            i18n ("<qt>A policy already exists for"
+                                  "<center><b>%1</b></center>"
+                                  "Do you want to replace it?</qt>", domain),
+                            i18nc ("@title:window", "Duplicate Policy"),
+                            KGuiItem (i18n ("Replace")));
             if (res == KMessageBox::Continue) {
-                m_pDomainPolicy[domain] = KCookieAdvice::adviceToStr (advice);
+                mDomainPolicyMap[domain] = KCookieAdvice::adviceToStr(advice);
                 item->setText (0, domain);
-                item->setText (1, i18n (m_pDomainPolicy.value(domain)));
+                item->setText (1, i18n (mDomainPolicyMap.value(domain)));
                 configChanged();
                 return true;
             } else
                 return true;  // User Cancelled!!
         }
-        item = mUi.lvDomainPolicy->itemBelow (item);
+        item = mUi.policyTreeWidget->itemBelow (item);
     }
     return false;
 }
@@ -253,12 +246,12 @@ void KCookiesPolicies::deletePressed()
 {
     QTreeWidgetItem* nextItem = 0L;
 
-    Q_FOREACH (QTreeWidgetItem * item, mUi.lvDomainPolicy->selectedItems()) {
-        nextItem = mUi.lvDomainPolicy->itemBelow (item);
+    Q_FOREACH (QTreeWidgetItem * item, mUi.policyTreeWidget->selectedItems()) {
+        nextItem = mUi.policyTreeWidget->itemBelow (item);
         if (!nextItem)
-            nextItem = mUi.lvDomainPolicy->itemAbove (item);
+            nextItem = mUi.policyTreeWidget->itemAbove (item);
 
-        m_pDomainPolicy.remove (item->text(0));
+        mDomainPolicyMap.remove (item->text(0));
         delete item;
     }
 
@@ -271,52 +264,50 @@ void KCookiesPolicies::deletePressed()
 
 void KCookiesPolicies::deleteAllPressed()
 {
-    m_pDomainPolicy.clear();
-    mUi.lvDomainPolicy->clear();
+    mDomainPolicyMap.clear();
+    mUi.policyTreeWidget->clear();
     updateButtons();
     configChanged();
 }
 
 void KCookiesPolicies::updateButtons()
 {
-    bool hasItems = mUi.lvDomainPolicy->topLevelItemCount() > 0;
+    bool hasItems = mUi.policyTreeWidget->topLevelItemCount() > 0;
 
-    mUi.pbChange->setEnabled ( (hasItems && d_itemsSelected == 1));
-    mUi.pbDelete->setEnabled ( (hasItems && d_itemsSelected > 0));
-    mUi.pbDeleteAll->setEnabled (hasItems);
+    mUi.pbChange->setEnabled((hasItems && mSelectedItemsCount == 1));
+    mUi.pbDelete->setEnabled((hasItems && mSelectedItemsCount > 0));
+    mUi.pbDeleteAll->setEnabled(hasItems);
 }
 
 void KCookiesPolicies::updateDomainList (const QStringList& domainConfig)
 {
-    mUi.lvDomainPolicy->clear();
+    mUi.policyTreeWidget->clear();
 
     QStringList::ConstIterator it = domainConfig.begin();
     for (; it != domainConfig.end(); ++it) {
         QString domain;
         KCookieAdvice::Value advice = KCookieAdvice::Dunno;
-
         splitDomainAdvice (*it, domain, advice);
-
         if (!domain.isEmpty()) {
-            QTreeWidgetItem* item = new QTreeWidgetItem (mUi.lvDomainPolicy, QStringList() << tolerantFromAce (domain.toLatin1()) <<
-                    i18n (KCookieAdvice::adviceToStr (advice)));
-            m_pDomainPolicy[item->text(0)] = KCookieAdvice::adviceToStr (advice);
+            QStringList items;
+            items << tolerantFromAce(domain.toLatin1()) << i18n(KCookieAdvice::adviceToStr(advice));
+            QTreeWidgetItem* item = new QTreeWidgetItem (mUi.policyTreeWidget, items);
+            mDomainPolicyMap[item->text(0)] = KCookieAdvice::adviceToStr(advice);
         }
     }    
 
-    mUi.lvDomainPolicy->sortItems(0, Qt::AscendingOrder);
+    mUi.policyTreeWidget->sortItems(0, Qt::AscendingOrder);
 }
 
 void KCookiesPolicies::selectionChanged ()
 {
-    d_itemsSelected = mUi.lvDomainPolicy->selectedItems().count();
-
+    mSelectedItemsCount = mUi.policyTreeWidget->selectedItems().count();
     updateButtons ();
 }
 
 void KCookiesPolicies::load()
 {
-    d_itemsSelected = 0;
+    mSelectedItemsCount = 0;
 
     KConfig cfg ("kcookiejarrc");
     KConfigGroup group = cfg.group ("Cookie Policy");
@@ -332,6 +323,9 @@ void KCookiesPolicies::load()
     case KCookieAdvice::Accept:
         mUi.rbPolicyAccept->setChecked (true);
         break;
+    case KCookieAdvice::AcceptForSession:
+        mUi.rbPolicyAcceptForSession->setChecked (true);
+        break;
     case KCookieAdvice::Reject:
         mUi.rbPolicyReject->setChecked (true);
         break;
@@ -346,13 +340,9 @@ void KCookiesPolicies::load()
 
     bool sessionCookies = group.readEntry ("AcceptSessionCookies", true);
     mUi.cbAutoAcceptSessionCookies->setChecked (sessionCookies);
-    bool cookieExpiration = group.readEntry ("IgnoreExpirationDate", false);
-    mUi.cbIgnoreCookieExpirationDate->setChecked (cookieExpiration);
     updateDomainList (group.readEntry ("CookieDomainAdvice", QStringList()));
 
     if (enableCookies) {
-        ignoreCookieExpirationDate (cookieExpiration);
-        autoAcceptSessionCookies (sessionCookies);
         updateButtons();
     }
 }
@@ -368,12 +358,12 @@ void KCookiesPolicies::save()
     group.writeEntry ("RejectCrossDomainCookies", state);
     state = mUi.cbAutoAcceptSessionCookies->isChecked();
     group.writeEntry ("AcceptSessionCookies", state);
-    state = mUi.cbIgnoreCookieExpirationDate->isChecked();
-    group.writeEntry ("IgnoreExpirationDate", state);
 
     QString advice;
     if (mUi.rbPolicyAccept->isChecked())
         advice = KCookieAdvice::adviceToStr (KCookieAdvice::Accept);
+    else if (mUi.rbPolicyAcceptForSession->isChecked())
+        advice = KCookieAdvice::adviceToStr (KCookieAdvice::AcceptForSession);
     else if (mUi.rbPolicyReject->isChecked())
         advice = KCookieAdvice::adviceToStr (KCookieAdvice::Reject);
     else
@@ -382,10 +372,10 @@ void KCookiesPolicies::save()
     group.writeEntry ("CookieGlobalAdvice", advice);
 
     QStringList domainConfig;
-    QMapIterator<QString, const char*> it (m_pDomainPolicy);
+    QMapIterator<QString, const char*> it (mDomainPolicyMap);
     while (it.hasNext()) {
         it.next();
-        QString policy = it.key();
+        QString policy = tolerantToAce(it.key());
         policy += QLatin1Char (':');
         policy += QLatin1String (it.value());
         domainConfig << policy;
@@ -418,12 +408,12 @@ void KCookiesPolicies::defaults()
     mUi.cbEnableCookies->setChecked (true);
     mUi.rbPolicyAsk->setChecked (true);
     mUi.rbPolicyAccept->setChecked (false);
+    mUi.rbPolicyAcceptForSession->setChecked (false);
     mUi.rbPolicyReject->setChecked (false);
     mUi.cbRejectCrossDomainCookies->setChecked (true);
-    mUi.cbAutoAcceptSessionCookies->setChecked (true);
-    mUi.cbIgnoreCookieExpirationDate->setChecked (false);
-    mUi.lvDomainPolicy->clear();
-    m_pDomainPolicy.clear();
+    mUi.cbAutoAcceptSessionCookies->setChecked (false);
+    mUi.policyTreeWidget->clear();
+    mDomainPolicyMap.clear();
 
     cookiesEnabled (mUi.cbEnableCookies->isChecked());
     updateButtons();
